"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FolderXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___FolderXTimeouts = FolderXTimeouts

@typing_extensions.final
class Folder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    display_name: builtins.str
    folder_id: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    name: builtins.str
    parent: builtins.str
    @property
    def timeouts(self) -> global___FolderXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        display_name: builtins.str = ...,
        folder_id: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        timeouts: global___FolderXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "display_name", b"display_name", "folder_id", b"folder_id", "id", b"id", "lifecycle_state", b"lifecycle_state", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___Folder = Folder

@typing_extensions.final
class FolderAccessApprovalSettingsXEnrolledServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_PRODUCT_FIELD_NUMBER: builtins.int
    ENROLLMENT_LEVEL_FIELD_NUMBER: builtins.int
    cloud_product: builtins.str
    enrollment_level: builtins.str
    def __init__(
        self,
        *,
        cloud_product: builtins.str = ...,
        enrollment_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_product", b"cloud_product", "enrollment_level", b"enrollment_level"]) -> None: ...

global___FolderAccessApprovalSettingsXEnrolledServices = FolderAccessApprovalSettingsXEnrolledServices

@typing_extensions.final
class FolderAccessApprovalSettingsXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___FolderAccessApprovalSettingsXTimeouts = FolderAccessApprovalSettingsXTimeouts

@typing_extensions.final
class FolderAccessApprovalSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_KEY_VERSION_FIELD_NUMBER: builtins.int
    ANCESTOR_HAS_ACTIVE_KEY_VERSION_FIELD_NUMBER: builtins.int
    ENROLLED_ANCESTOR_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INVALID_KEY_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOTIFICATION_EMAILS_FIELD_NUMBER: builtins.int
    ENROLLED_SERVICES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    active_key_version: builtins.str
    ancestor_has_active_key_version: builtins.bool
    enrolled_ancestor: builtins.bool
    folder_id: builtins.str
    id: builtins.str
    invalid_key_version: builtins.bool
    name: builtins.str
    @property
    def notification_emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def enrolled_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FolderAccessApprovalSettingsXEnrolledServices]: ...
    @property
    def timeouts(self) -> global___FolderAccessApprovalSettingsXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        active_key_version: builtins.str = ...,
        ancestor_has_active_key_version: builtins.bool = ...,
        enrolled_ancestor: builtins.bool = ...,
        folder_id: builtins.str = ...,
        id: builtins.str = ...,
        invalid_key_version: builtins.bool = ...,
        name: builtins.str = ...,
        notification_emails: collections.abc.Iterable[builtins.str] | None = ...,
        enrolled_services: collections.abc.Iterable[global___FolderAccessApprovalSettingsXEnrolledServices] | None = ...,
        timeouts: global___FolderAccessApprovalSettingsXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_key_version", b"active_key_version", "ancestor_has_active_key_version", b"ancestor_has_active_key_version", "enrolled_ancestor", b"enrolled_ancestor", "enrolled_services", b"enrolled_services", "folder_id", b"folder_id", "id", b"id", "invalid_key_version", b"invalid_key_version", "name", b"name", "notification_emails", b"notification_emails", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___FolderAccessApprovalSettings = FolderAccessApprovalSettings

@typing_extensions.final
class FolderIamAuditConfigXAuditLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXEMPTED_MEMBERS_FIELD_NUMBER: builtins.int
    LOG_TYPE_FIELD_NUMBER: builtins.int
    @property
    def exempted_members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    log_type: builtins.str
    def __init__(
        self,
        *,
        exempted_members: collections.abc.Iterable[builtins.str] | None = ...,
        log_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exempted_members", b"exempted_members", "log_type", b"log_type"]) -> None: ...

global___FolderIamAuditConfigXAuditLogConfig = FolderIamAuditConfigXAuditLogConfig

@typing_extensions.final
class FolderIamAuditConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    AUDIT_LOG_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    folder: builtins.str
    id: builtins.str
    service: builtins.str
    @property
    def audit_log_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FolderIamAuditConfigXAuditLogConfig]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        service: builtins.str = ...,
        audit_log_config: collections.abc.Iterable[global___FolderIamAuditConfigXAuditLogConfig] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_log_config", b"audit_log_config", "etag", b"etag", "folder", b"folder", "id", b"id", "resource_info", b"resource_info", "service", b"service"]) -> None: ...

global___FolderIamAuditConfig = FolderIamAuditConfig

@typing_extensions.final
class FolderIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___FolderIamBindingXCondition = FolderIamBindingXCondition

@typing_extensions.final
class FolderIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    folder: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___FolderIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___FolderIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "folder", b"folder", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___FolderIamBinding = FolderIamBinding

@typing_extensions.final
class FolderIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___FolderIamMemberXCondition = FolderIamMemberXCondition

@typing_extensions.final
class FolderIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    folder: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___FolderIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___FolderIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "folder", b"folder", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___FolderIamMember = FolderIamMember

@typing_extensions.final
class FolderIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    folder: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "folder", b"folder", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___FolderIamPolicy = FolderIamPolicy

@typing_extensions.final
class FolderOrganizationPolicyXBooleanPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENFORCED_FIELD_NUMBER: builtins.int
    enforced: builtins.bool
    def __init__(
        self,
        *,
        enforced: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enforced", b"enforced"]) -> None: ...

global___FolderOrganizationPolicyXBooleanPolicy = FolderOrganizationPolicyXBooleanPolicy

@typing_extensions.final
class FolderOrganizationPolicyXListPolicyXAllow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALL_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    all: builtins.bool
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        all: builtins.bool = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "values", b"values"]) -> None: ...

global___FolderOrganizationPolicyXListPolicyXAllow = FolderOrganizationPolicyXListPolicyXAllow

@typing_extensions.final
class FolderOrganizationPolicyXListPolicyXDeny(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALL_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    all: builtins.bool
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        all: builtins.bool = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "values", b"values"]) -> None: ...

global___FolderOrganizationPolicyXListPolicyXDeny = FolderOrganizationPolicyXListPolicyXDeny

@typing_extensions.final
class FolderOrganizationPolicyXListPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INHERIT_FROM_PARENT_FIELD_NUMBER: builtins.int
    SUGGESTED_VALUE_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    DENY_FIELD_NUMBER: builtins.int
    inherit_from_parent: builtins.bool
    suggested_value: builtins.str
    @property
    def allow(self) -> global___FolderOrganizationPolicyXListPolicyXAllow: ...
    @property
    def deny(self) -> global___FolderOrganizationPolicyXListPolicyXDeny: ...
    def __init__(
        self,
        *,
        inherit_from_parent: builtins.bool = ...,
        suggested_value: builtins.str = ...,
        allow: global___FolderOrganizationPolicyXListPolicyXAllow | None = ...,
        deny: global___FolderOrganizationPolicyXListPolicyXDeny | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allow", b"allow", "deny", b"deny"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow", b"allow", "deny", b"deny", "inherit_from_parent", b"inherit_from_parent", "suggested_value", b"suggested_value"]) -> None: ...

global___FolderOrganizationPolicyXListPolicy = FolderOrganizationPolicyXListPolicy

@typing_extensions.final
class FolderOrganizationPolicyXRestorePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_FIELD_NUMBER: builtins.int
    default: builtins.bool
    def __init__(
        self,
        *,
        default: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default", b"default"]) -> None: ...

global___FolderOrganizationPolicyXRestorePolicy = FolderOrganizationPolicyXRestorePolicy

@typing_extensions.final
class FolderOrganizationPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___FolderOrganizationPolicyXTimeouts = FolderOrganizationPolicyXTimeouts

@typing_extensions.final
class FolderOrganizationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    BOOLEAN_POLICY_FIELD_NUMBER: builtins.int
    LIST_POLICY_FIELD_NUMBER: builtins.int
    RESTORE_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    constraint: builtins.str
    etag: builtins.str
    folder: builtins.str
    id: builtins.str
    update_time: builtins.str
    version: builtins.float
    @property
    def boolean_policy(self) -> global___FolderOrganizationPolicyXBooleanPolicy: ...
    @property
    def list_policy(self) -> global___FolderOrganizationPolicyXListPolicy: ...
    @property
    def restore_policy(self) -> global___FolderOrganizationPolicyXRestorePolicy: ...
    @property
    def timeouts(self) -> global___FolderOrganizationPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        constraint: builtins.str = ...,
        etag: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        update_time: builtins.str = ...,
        version: builtins.float = ...,
        boolean_policy: global___FolderOrganizationPolicyXBooleanPolicy | None = ...,
        list_policy: global___FolderOrganizationPolicyXListPolicy | None = ...,
        restore_policy: global___FolderOrganizationPolicyXRestorePolicy | None = ...,
        timeouts: global___FolderOrganizationPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["boolean_policy", b"boolean_policy", "list_policy", b"list_policy", "resource_info", b"resource_info", "restore_policy", b"restore_policy", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boolean_policy", b"boolean_policy", "constraint", b"constraint", "etag", b"etag", "folder", b"folder", "id", b"id", "list_policy", b"list_policy", "resource_info", b"resource_info", "restore_policy", b"restore_policy", "timeouts", b"timeouts", "update_time", b"update_time", "version", b"version"]) -> None: ...

global___FolderOrganizationPolicy = FolderOrganizationPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import gcp.gcp_compute_backend_pb2
import gcp.gcp_compute_forwarding_pb2
import gcp.gcp_compute_global_pb2
import gcp.gcp_compute_health_pb2
import gcp.gcp_compute_http_pb2
import gcp.gcp_compute_https_pb2
import gcp.gcp_compute_region_pb2
import gcp.gcp_compute_ssl_pb2
import gcp.gcp_compute_target_pb2
import gcp.gcp_compute_url_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleLoadBalancer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_BACKEND_BUCKET_FIELD_NUMBER: builtins.int
    COMPUTE_BACKEND_BUCKET_SIGNED_URL_KEY_FIELD_NUMBER: builtins.int
    COMPUTE_BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    COMPUTE_BACKEND_SERVICE_SIGNED_URL_KEY_FIELD_NUMBER: builtins.int
    COMPUTE_FORWARDING_RULE_FIELD_NUMBER: builtins.int
    COMPUTE_GLOBAL_FORWARDING_RULE_FIELD_NUMBER: builtins.int
    COMPUTE_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    COMPUTE_HTTP_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    COMPUTE_HTTPS_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    COMPUTE_REGION_BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    COMPUTE_REGION_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    COMPUTE_REGION_SSL_CERTIFICATE_FIELD_NUMBER: builtins.int
    COMPUTE_REGION_TARGET_HTTP_PROXY_FIELD_NUMBER: builtins.int
    COMPUTE_REGION_TARGET_HTTPS_PROXY_FIELD_NUMBER: builtins.int
    COMPUTE_REGION_URL_MAP_FIELD_NUMBER: builtins.int
    COMPUTE_SSL_CERTIFICATE_FIELD_NUMBER: builtins.int
    COMPUTE_SSL_POLICY_FIELD_NUMBER: builtins.int
    COMPUTE_TARGET_GRPC_PROXY_FIELD_NUMBER: builtins.int
    COMPUTE_TARGET_HTTP_PROXY_FIELD_NUMBER: builtins.int
    COMPUTE_TARGET_HTTPS_PROXY_FIELD_NUMBER: builtins.int
    COMPUTE_TARGET_POOL_FIELD_NUMBER: builtins.int
    COMPUTE_TARGET_SSL_PROXY_FIELD_NUMBER: builtins.int
    COMPUTE_TARGET_TCP_PROXY_FIELD_NUMBER: builtins.int
    COMPUTE_URL_MAP_FIELD_NUMBER: builtins.int
    @property
    def compute_backend_bucket(self) -> gcp.gcp_compute_backend_pb2.ComputeBackendBucket: ...
    @property
    def compute_backend_bucket_signed_url_key(self) -> gcp.gcp_compute_backend_pb2.ComputeBackendBucketSignedUrlKey: ...
    @property
    def compute_backend_service(self) -> gcp.gcp_compute_backend_pb2.ComputeBackendService: ...
    @property
    def compute_backend_service_signed_url_key(self) -> gcp.gcp_compute_backend_pb2.ComputeBackendServiceSignedUrlKey: ...
    @property
    def compute_forwarding_rule(self) -> gcp.gcp_compute_forwarding_pb2.ComputeForwardingRule: ...
    @property
    def compute_global_forwarding_rule(self) -> gcp.gcp_compute_global_pb2.ComputeGlobalForwardingRule: ...
    @property
    def compute_health_check(self) -> gcp.gcp_compute_health_pb2.ComputeHealthCheck: ...
    @property
    def compute_http_health_check(self) -> gcp.gcp_compute_http_pb2.ComputeHttpHealthCheck: ...
    @property
    def compute_https_health_check(self) -> gcp.gcp_compute_https_pb2.ComputeHttpsHealthCheck: ...
    @property
    def compute_region_backend_service(self) -> gcp.gcp_compute_region_pb2.ComputeRegionBackendService: ...
    @property
    def compute_region_health_check(self) -> gcp.gcp_compute_region_pb2.ComputeRegionHealthCheck: ...
    @property
    def compute_region_ssl_certificate(self) -> gcp.gcp_compute_region_pb2.ComputeRegionSslCertificate: ...
    @property
    def compute_region_target_http_proxy(self) -> gcp.gcp_compute_region_pb2.ComputeRegionTargetHttpProxy: ...
    @property
    def compute_region_target_https_proxy(self) -> gcp.gcp_compute_region_pb2.ComputeRegionTargetHttpsProxy: ...
    @property
    def compute_region_url_map(self) -> gcp.gcp_compute_region_pb2.ComputeRegionUrlMap: ...
    @property
    def compute_ssl_certificate(self) -> gcp.gcp_compute_ssl_pb2.ComputeSslCertificate: ...
    @property
    def compute_ssl_policy(self) -> gcp.gcp_compute_ssl_pb2.ComputeSslPolicy: ...
    @property
    def compute_target_grpc_proxy(self) -> gcp.gcp_compute_target_pb2.ComputeTargetGrpcProxy: ...
    @property
    def compute_target_http_proxy(self) -> gcp.gcp_compute_target_pb2.ComputeTargetHttpProxy: ...
    @property
    def compute_target_https_proxy(self) -> gcp.gcp_compute_target_pb2.ComputeTargetHttpsProxy: ...
    @property
    def compute_target_pool(self) -> gcp.gcp_compute_target_pb2.ComputeTargetPool: ...
    @property
    def compute_target_ssl_proxy(self) -> gcp.gcp_compute_target_pb2.ComputeTargetSslProxy: ...
    @property
    def compute_target_tcp_proxy(self) -> gcp.gcp_compute_target_pb2.ComputeTargetTcpProxy: ...
    @property
    def compute_url_map(self) -> gcp.gcp_compute_url_pb2.ComputeUrlMap: ...
    def __init__(
        self,
        *,
        compute_backend_bucket: gcp.gcp_compute_backend_pb2.ComputeBackendBucket | None = ...,
        compute_backend_bucket_signed_url_key: gcp.gcp_compute_backend_pb2.ComputeBackendBucketSignedUrlKey | None = ...,
        compute_backend_service: gcp.gcp_compute_backend_pb2.ComputeBackendService | None = ...,
        compute_backend_service_signed_url_key: gcp.gcp_compute_backend_pb2.ComputeBackendServiceSignedUrlKey | None = ...,
        compute_forwarding_rule: gcp.gcp_compute_forwarding_pb2.ComputeForwardingRule | None = ...,
        compute_global_forwarding_rule: gcp.gcp_compute_global_pb2.ComputeGlobalForwardingRule | None = ...,
        compute_health_check: gcp.gcp_compute_health_pb2.ComputeHealthCheck | None = ...,
        compute_http_health_check: gcp.gcp_compute_http_pb2.ComputeHttpHealthCheck | None = ...,
        compute_https_health_check: gcp.gcp_compute_https_pb2.ComputeHttpsHealthCheck | None = ...,
        compute_region_backend_service: gcp.gcp_compute_region_pb2.ComputeRegionBackendService | None = ...,
        compute_region_health_check: gcp.gcp_compute_region_pb2.ComputeRegionHealthCheck | None = ...,
        compute_region_ssl_certificate: gcp.gcp_compute_region_pb2.ComputeRegionSslCertificate | None = ...,
        compute_region_target_http_proxy: gcp.gcp_compute_region_pb2.ComputeRegionTargetHttpProxy | None = ...,
        compute_region_target_https_proxy: gcp.gcp_compute_region_pb2.ComputeRegionTargetHttpsProxy | None = ...,
        compute_region_url_map: gcp.gcp_compute_region_pb2.ComputeRegionUrlMap | None = ...,
        compute_ssl_certificate: gcp.gcp_compute_ssl_pb2.ComputeSslCertificate | None = ...,
        compute_ssl_policy: gcp.gcp_compute_ssl_pb2.ComputeSslPolicy | None = ...,
        compute_target_grpc_proxy: gcp.gcp_compute_target_pb2.ComputeTargetGrpcProxy | None = ...,
        compute_target_http_proxy: gcp.gcp_compute_target_pb2.ComputeTargetHttpProxy | None = ...,
        compute_target_https_proxy: gcp.gcp_compute_target_pb2.ComputeTargetHttpsProxy | None = ...,
        compute_target_pool: gcp.gcp_compute_target_pb2.ComputeTargetPool | None = ...,
        compute_target_ssl_proxy: gcp.gcp_compute_target_pb2.ComputeTargetSslProxy | None = ...,
        compute_target_tcp_proxy: gcp.gcp_compute_target_pb2.ComputeTargetTcpProxy | None = ...,
        compute_url_map: gcp.gcp_compute_url_pb2.ComputeUrlMap | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_backend_bucket", b"compute_backend_bucket", "compute_backend_bucket_signed_url_key", b"compute_backend_bucket_signed_url_key", "compute_backend_service", b"compute_backend_service", "compute_backend_service_signed_url_key", b"compute_backend_service_signed_url_key", "compute_forwarding_rule", b"compute_forwarding_rule", "compute_global_forwarding_rule", b"compute_global_forwarding_rule", "compute_health_check", b"compute_health_check", "compute_http_health_check", b"compute_http_health_check", "compute_https_health_check", b"compute_https_health_check", "compute_region_backend_service", b"compute_region_backend_service", "compute_region_health_check", b"compute_region_health_check", "compute_region_ssl_certificate", b"compute_region_ssl_certificate", "compute_region_target_http_proxy", b"compute_region_target_http_proxy", "compute_region_target_https_proxy", b"compute_region_target_https_proxy", "compute_region_url_map", b"compute_region_url_map", "compute_ssl_certificate", b"compute_ssl_certificate", "compute_ssl_policy", b"compute_ssl_policy", "compute_target_grpc_proxy", b"compute_target_grpc_proxy", "compute_target_http_proxy", b"compute_target_http_proxy", "compute_target_https_proxy", b"compute_target_https_proxy", "compute_target_pool", b"compute_target_pool", "compute_target_ssl_proxy", b"compute_target_ssl_proxy", "compute_target_tcp_proxy", b"compute_target_tcp_proxy", "compute_url_map", b"compute_url_map"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_backend_bucket", b"compute_backend_bucket", "compute_backend_bucket_signed_url_key", b"compute_backend_bucket_signed_url_key", "compute_backend_service", b"compute_backend_service", "compute_backend_service_signed_url_key", b"compute_backend_service_signed_url_key", "compute_forwarding_rule", b"compute_forwarding_rule", "compute_global_forwarding_rule", b"compute_global_forwarding_rule", "compute_health_check", b"compute_health_check", "compute_http_health_check", b"compute_http_health_check", "compute_https_health_check", b"compute_https_health_check", "compute_region_backend_service", b"compute_region_backend_service", "compute_region_health_check", b"compute_region_health_check", "compute_region_ssl_certificate", b"compute_region_ssl_certificate", "compute_region_target_http_proxy", b"compute_region_target_http_proxy", "compute_region_target_https_proxy", b"compute_region_target_https_proxy", "compute_region_url_map", b"compute_region_url_map", "compute_ssl_certificate", b"compute_ssl_certificate", "compute_ssl_policy", b"compute_ssl_policy", "compute_target_grpc_proxy", b"compute_target_grpc_proxy", "compute_target_http_proxy", b"compute_target_http_proxy", "compute_target_https_proxy", b"compute_target_https_proxy", "compute_target_pool", b"compute_target_pool", "compute_target_ssl_proxy", b"compute_target_ssl_proxy", "compute_target_tcp_proxy", b"compute_target_tcp_proxy", "compute_url_map", b"compute_url_map"]) -> None: ...

global___GoogleLoadBalancer = GoogleLoadBalancer



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DBInstanceDBInstanceRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FEATURE_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    feature_name: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        feature_name: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_name", b"feature_name", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___DBInstanceDBInstanceRole = DBInstanceDBInstanceRole

@typing_extensions.final
class DBInstanceProcessorFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DBInstanceProcessorFeature = DBInstanceProcessorFeature

@typing_extensions.final
class DBInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOCATED_STORAGE_FIELD_NUMBER: builtins.int
    ALLOW_MAJOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    ASSOCIATED_ROLES_FIELD_NUMBER: builtins.int
    AUTO_MINOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    BACKUP_RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    CA_CERTIFICATE_IDENTIFIER_FIELD_NUMBER: builtins.int
    CHARACTER_SET_NAME_FIELD_NUMBER: builtins.int
    COPY_TAGS_TO_SNAPSHOT_FIELD_NUMBER: builtins.int
    DB_CLUSTER_IDENTIFIER_FIELD_NUMBER: builtins.int
    DB_INSTANCE_CLASS_FIELD_NUMBER: builtins.int
    DB_INSTANCE_IDENTIFIER_FIELD_NUMBER: builtins.int
    DB_NAME_FIELD_NUMBER: builtins.int
    DB_PARAMETER_GROUP_NAME_FIELD_NUMBER: builtins.int
    DB_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    DB_SNAPSHOT_IDENTIFIER_FIELD_NUMBER: builtins.int
    DB_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    DELETE_AUTOMATED_BACKUPS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    DOMAIN_IAM_ROLE_NAME_FIELD_NUMBER: builtins.int
    ENABLE_CLOUDWATCH_LOGS_EXPORTS_FIELD_NUMBER: builtins.int
    ENABLE_IAM_DATABASE_AUTHENTICATION_FIELD_NUMBER: builtins.int
    ENABLE_PERFORMANCE_INSIGHTS_FIELD_NUMBER: builtins.int
    ENGINE_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    LICENSE_MODEL_FIELD_NUMBER: builtins.int
    MASTER_USER_PASSWORD_FIELD_NUMBER: builtins.int
    MASTER_USERNAME_FIELD_NUMBER: builtins.int
    MAX_ALLOCATED_STORAGE_FIELD_NUMBER: builtins.int
    MONITORING_INTERVAL_FIELD_NUMBER: builtins.int
    MONITORING_ROLE_ARN_FIELD_NUMBER: builtins.int
    MULTI_AZ_FIELD_NUMBER: builtins.int
    OPTION_GROUP_NAME_FIELD_NUMBER: builtins.int
    PERFORMANCE_INSIGHTS_KMS_KEY_ID_FIELD_NUMBER: builtins.int
    PERFORMANCE_INSIGHTS_RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PREFERRED_BACKUP_WINDOW_FIELD_NUMBER: builtins.int
    PREFERRED_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PROCESSOR_FEATURES_FIELD_NUMBER: builtins.int
    PROMOTION_TIER_FIELD_NUMBER: builtins.int
    PUBLICLY_ACCESSIBLE_FIELD_NUMBER: builtins.int
    SOURCE_DB_INSTANCE_IDENTIFIER_FIELD_NUMBER: builtins.int
    SOURCE_REGION_FIELD_NUMBER: builtins.int
    STORAGE_ENCRYPTED_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    USE_DEFAULT_PROCESSOR_FEATURES_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    allocated_storage: builtins.str
    allow_major_version_upgrade: builtins.bool
    @property
    def associated_roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBInstanceDBInstanceRole]: ...
    auto_minor_version_upgrade: builtins.bool
    availability_zone: builtins.str
    backup_retention_period: builtins.int
    ca_certificate_identifier: builtins.str
    character_set_name: builtins.str
    copy_tags_to_snapshot: builtins.bool
    db_cluster_identifier: builtins.str
    db_instance_class: builtins.str
    db_instance_identifier: builtins.str
    db_name: builtins.str
    db_parameter_group_name: builtins.str
    @property
    def db_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    db_snapshot_identifier: builtins.str
    db_subnet_group_name: builtins.str
    delete_automated_backups: builtins.bool
    deletion_protection: builtins.bool
    domain: builtins.str
    domain_iam_role_name: builtins.str
    @property
    def enable_cloudwatch_logs_exports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_iam_database_authentication: builtins.bool
    enable_performance_insights: builtins.bool
    engine: builtins.str
    engine_version: builtins.str
    iops: builtins.int
    kms_key_id: builtins.str
    license_model: builtins.str
    master_user_password: builtins.str
    master_username: builtins.str
    max_allocated_storage: builtins.int
    monitoring_interval: builtins.int
    monitoring_role_arn: builtins.str
    multi_az: builtins.bool
    option_group_name: builtins.str
    performance_insights_kms_key_id: builtins.str
    performance_insights_retention_period: builtins.int
    port: builtins.str
    preferred_backup_window: builtins.str
    preferred_maintenance_window: builtins.str
    @property
    def processor_features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBInstanceProcessorFeature]: ...
    promotion_tier: builtins.int
    publicly_accessible: builtins.bool
    source_db_instance_identifier: builtins.str
    source_region: builtins.str
    storage_encrypted: builtins.bool
    storage_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    timezone: builtins.str
    use_default_processor_features: builtins.bool
    @property
    def vpc_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allocated_storage: builtins.str = ...,
        allow_major_version_upgrade: builtins.bool = ...,
        associated_roles: collections.abc.Iterable[global___DBInstanceDBInstanceRole] | None = ...,
        auto_minor_version_upgrade: builtins.bool = ...,
        availability_zone: builtins.str = ...,
        backup_retention_period: builtins.int = ...,
        ca_certificate_identifier: builtins.str = ...,
        character_set_name: builtins.str = ...,
        copy_tags_to_snapshot: builtins.bool = ...,
        db_cluster_identifier: builtins.str = ...,
        db_instance_class: builtins.str = ...,
        db_instance_identifier: builtins.str = ...,
        db_name: builtins.str = ...,
        db_parameter_group_name: builtins.str = ...,
        db_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        db_snapshot_identifier: builtins.str = ...,
        db_subnet_group_name: builtins.str = ...,
        delete_automated_backups: builtins.bool = ...,
        deletion_protection: builtins.bool = ...,
        domain: builtins.str = ...,
        domain_iam_role_name: builtins.str = ...,
        enable_cloudwatch_logs_exports: collections.abc.Iterable[builtins.str] | None = ...,
        enable_iam_database_authentication: builtins.bool = ...,
        enable_performance_insights: builtins.bool = ...,
        engine: builtins.str = ...,
        engine_version: builtins.str = ...,
        iops: builtins.int = ...,
        kms_key_id: builtins.str = ...,
        license_model: builtins.str = ...,
        master_user_password: builtins.str = ...,
        master_username: builtins.str = ...,
        max_allocated_storage: builtins.int = ...,
        monitoring_interval: builtins.int = ...,
        monitoring_role_arn: builtins.str = ...,
        multi_az: builtins.bool = ...,
        option_group_name: builtins.str = ...,
        performance_insights_kms_key_id: builtins.str = ...,
        performance_insights_retention_period: builtins.int = ...,
        port: builtins.str = ...,
        preferred_backup_window: builtins.str = ...,
        preferred_maintenance_window: builtins.str = ...,
        processor_features: collections.abc.Iterable[global___DBInstanceProcessorFeature] | None = ...,
        promotion_tier: builtins.int = ...,
        publicly_accessible: builtins.bool = ...,
        source_db_instance_identifier: builtins.str = ...,
        source_region: builtins.str = ...,
        storage_encrypted: builtins.bool = ...,
        storage_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        timezone: builtins.str = ...,
        use_default_processor_features: builtins.bool = ...,
        vpc_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocated_storage", b"allocated_storage", "allow_major_version_upgrade", b"allow_major_version_upgrade", "associated_roles", b"associated_roles", "auto_minor_version_upgrade", b"auto_minor_version_upgrade", "availability_zone", b"availability_zone", "backup_retention_period", b"backup_retention_period", "ca_certificate_identifier", b"ca_certificate_identifier", "character_set_name", b"character_set_name", "copy_tags_to_snapshot", b"copy_tags_to_snapshot", "db_cluster_identifier", b"db_cluster_identifier", "db_instance_class", b"db_instance_class", "db_instance_identifier", b"db_instance_identifier", "db_name", b"db_name", "db_parameter_group_name", b"db_parameter_group_name", "db_security_groups", b"db_security_groups", "db_snapshot_identifier", b"db_snapshot_identifier", "db_subnet_group_name", b"db_subnet_group_name", "delete_automated_backups", b"delete_automated_backups", "deletion_protection", b"deletion_protection", "domain", b"domain", "domain_iam_role_name", b"domain_iam_role_name", "enable_cloudwatch_logs_exports", b"enable_cloudwatch_logs_exports", "enable_iam_database_authentication", b"enable_iam_database_authentication", "enable_performance_insights", b"enable_performance_insights", "engine", b"engine", "engine_version", b"engine_version", "iops", b"iops", "kms_key_id", b"kms_key_id", "license_model", b"license_model", "master_user_password", b"master_user_password", "master_username", b"master_username", "max_allocated_storage", b"max_allocated_storage", "monitoring_interval", b"monitoring_interval", "monitoring_role_arn", b"monitoring_role_arn", "multi_az", b"multi_az", "option_group_name", b"option_group_name", "performance_insights_kms_key_id", b"performance_insights_kms_key_id", "performance_insights_retention_period", b"performance_insights_retention_period", "port", b"port", "preferred_backup_window", b"preferred_backup_window", "preferred_maintenance_window", b"preferred_maintenance_window", "processor_features", b"processor_features", "promotion_tier", b"promotion_tier", "publicly_accessible", b"publicly_accessible", "resource_info", b"resource_info", "source_db_instance_identifier", b"source_db_instance_identifier", "source_region", b"source_region", "storage_encrypted", b"storage_encrypted", "storage_type", b"storage_type", "tags", b"tags", "timezone", b"timezone", "use_default_processor_features", b"use_default_processor_features", "vpc_security_groups", b"vpc_security_groups"]) -> None: ...

global___DBInstance = DBInstance

@typing_extensions.final
class RDS_DBInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DB_INSTANCE_FIELD_NUMBER: builtins.int
    DB_PARAMETER_GROUP_FIELD_NUMBER: builtins.int
    DB_PROXY_FIELD_NUMBER: builtins.int
    DB_PROXY_TARGET_GROUP_FIELD_NUMBER: builtins.int
    DB_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    DB_SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    DB_SUBNET_GROUP_FIELD_NUMBER: builtins.int
    EVENT_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    OPTION_GROUP_FIELD_NUMBER: builtins.int
    @property
    def db_instance(self) -> global___DBInstance: ...
    @property
    def db_parameter_group(self) -> global___DBParameterGroup: ...
    @property
    def db_proxy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBProxy]: ...
    @property
    def db_proxy_target_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBProxyTargetGroup]: ...
    @property
    def db_security_group(self) -> global___DBSecurityGroup: ...
    @property
    def db_security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBSecurityGroupIngress]: ...
    @property
    def db_subnet_group(self) -> global___DBSubnetGroup: ...
    @property
    def event_subscription(self) -> global___EventSubscription: ...
    @property
    def option_group(self) -> global___OptionGroup: ...
    def __init__(
        self,
        *,
        db_instance: global___DBInstance | None = ...,
        db_parameter_group: global___DBParameterGroup | None = ...,
        db_proxy: collections.abc.Iterable[global___DBProxy] | None = ...,
        db_proxy_target_group: collections.abc.Iterable[global___DBProxyTargetGroup] | None = ...,
        db_security_group: global___DBSecurityGroup | None = ...,
        db_security_group_ingress: collections.abc.Iterable[global___DBSecurityGroupIngress] | None = ...,
        db_subnet_group: global___DBSubnetGroup | None = ...,
        event_subscription: global___EventSubscription | None = ...,
        option_group: global___OptionGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["db_instance", b"db_instance", "db_parameter_group", b"db_parameter_group", "db_security_group", b"db_security_group", "db_subnet_group", b"db_subnet_group", "event_subscription", b"event_subscription", "option_group", b"option_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_instance", b"db_instance", "db_parameter_group", b"db_parameter_group", "db_proxy", b"db_proxy", "db_proxy_target_group", b"db_proxy_target_group", "db_security_group", b"db_security_group", "db_security_group_ingress", b"db_security_group_ingress", "db_subnet_group", b"db_subnet_group", "event_subscription", b"event_subscription", "option_group", b"option_group"]) -> None: ...

global___RDS_DBInstance = RDS_DBInstance

@typing_extensions.final
class DBParameterGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    family: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        family: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "family", b"family", "parameters", b"parameters", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DBParameterGroup = DBParameterGroup

@typing_extensions.final
class DBProxyTagFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DBProxyTagFormat = DBProxyTagFormat

@typing_extensions.final
class DBProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_PROXY_NAME_FIELD_NUMBER: builtins.int
    DEBUG_LOGGING_FIELD_NUMBER: builtins.int
    ENGINE_FAMILY_FIELD_NUMBER: builtins.int
    IDLE_CLIENT_TIMEOUT_FIELD_NUMBER: builtins.int
    REQUIRE_TLS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    VPC_SUBNET_IDS_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    db_proxy_name: builtins.str
    debug_logging: builtins.bool
    engine_family: builtins.str
    idle_client_timeout: builtins.int
    require_tls: builtins.bool
    role_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBProxyTagFormat]: ...
    @property
    def vpc_security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def vpc_subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBProxyAuth]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_proxy_name: builtins.str = ...,
        debug_logging: builtins.bool = ...,
        engine_family: builtins.str = ...,
        idle_client_timeout: builtins.int = ...,
        require_tls: builtins.bool = ...,
        role_arn: builtins.str = ...,
        tags: collections.abc.Iterable[global___DBProxyTagFormat] | None = ...,
        vpc_security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        auth: collections.abc.Iterable[global___DBProxyAuth] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "db_proxy_name", b"db_proxy_name", "debug_logging", b"debug_logging", "engine_family", b"engine_family", "idle_client_timeout", b"idle_client_timeout", "require_tls", b"require_tls", "resource_info", b"resource_info", "role_arn", b"role_arn", "tags", b"tags", "vpc_security_group_ids", b"vpc_security_group_ids", "vpc_subnet_ids", b"vpc_subnet_ids"]) -> None: ...

global___DBProxy = DBProxy

@typing_extensions.final
class DBProxyTargetGroupConnectionPoolConfigurationInfoFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PERCENT_FIELD_NUMBER: builtins.int
    MAX_IDLE_CONNECTIONS_PERCENT_FIELD_NUMBER: builtins.int
    CONNECTION_BORROW_TIMEOUT_FIELD_NUMBER: builtins.int
    SESSION_PINNING_FILTERS_FIELD_NUMBER: builtins.int
    INIT_QUERY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_connections_percent: builtins.int
    max_idle_connections_percent: builtins.int
    connection_borrow_timeout: builtins.int
    @property
    def session_pinning_filters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    init_query: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_connections_percent: builtins.int = ...,
        max_idle_connections_percent: builtins.int = ...,
        connection_borrow_timeout: builtins.int = ...,
        session_pinning_filters: collections.abc.Iterable[builtins.str] | None = ...,
        init_query: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_borrow_timeout", b"connection_borrow_timeout", "init_query", b"init_query", "max_connections_percent", b"max_connections_percent", "max_idle_connections_percent", b"max_idle_connections_percent", "resource_info", b"resource_info", "session_pinning_filters", b"session_pinning_filters"]) -> None: ...

global___DBProxyTargetGroupConnectionPoolConfigurationInfoFormat = DBProxyTargetGroupConnectionPoolConfigurationInfoFormat

@typing_extensions.final
class DBProxyTargetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_PROXY_NAME_FIELD_NUMBER: builtins.int
    TARGET_GROUP_NAME_FIELD_NUMBER: builtins.int
    CONNECTION_POOL_CONFIGURATION_INFO_FIELD_NUMBER: builtins.int
    DB_INSTANCE_IDENTIFIERS_FIELD_NUMBER: builtins.int
    DB_CLUSTER_IDENTIFIERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    db_proxy_name: builtins.str
    target_group_name: builtins.str
    @property
    def connection_pool_configuration_info(self) -> global___DBProxyTargetGroupConnectionPoolConfigurationInfoFormat: ...
    @property
    def db_instance_identifiers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def db_cluster_identifiers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_proxy_name: builtins.str = ...,
        target_group_name: builtins.str = ...,
        connection_pool_configuration_info: global___DBProxyTargetGroupConnectionPoolConfigurationInfoFormat | None = ...,
        db_instance_identifiers: collections.abc.Iterable[builtins.str] | None = ...,
        db_cluster_identifiers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection_pool_configuration_info", b"connection_pool_configuration_info", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_pool_configuration_info", b"connection_pool_configuration_info", "db_cluster_identifiers", b"db_cluster_identifiers", "db_instance_identifiers", b"db_instance_identifiers", "db_proxy_name", b"db_proxy_name", "resource_info", b"resource_info", "target_group_name", b"target_group_name"]) -> None: ...

global___DBProxyTargetGroup = DBProxyTargetGroup

@typing_extensions.final
class DBSecurityGroupIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CIDR_IP_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_OWNER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cidr_ip: builtins.str
    e_c2_security_group_id: builtins.str
    e_c2_security_group_name: builtins.str
    e_c2_security_group_owner_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cidr_ip: builtins.str = ...,
        e_c2_security_group_id: builtins.str = ...,
        e_c2_security_group_name: builtins.str = ...,
        e_c2_security_group_owner_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_ip", b"cidr_ip", "e_c2_security_group_id", b"e_c2_security_group_id", "e_c2_security_group_name", b"e_c2_security_group_name", "e_c2_security_group_owner_id", b"e_c2_security_group_owner_id", "resource_info", b"resource_info"]) -> None: ...

global___DBSecurityGroupIngress = DBSecurityGroupIngress

@typing_extensions.final
class DBSecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    E_C2_VPC_ID_FIELD_NUMBER: builtins.int
    GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def db_security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBSecurityGroupIngress]: ...
    e_c2_vpc_id: builtins.str
    group_description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_security_group_ingress: collections.abc.Iterable[global___DBSecurityGroupIngress] | None = ...,
        e_c2_vpc_id: builtins.str = ...,
        group_description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_security_group_ingress", b"db_security_group_ingress", "e_c2_vpc_id", b"e_c2_vpc_id", "group_description", b"group_description", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DBSecurityGroup = DBSecurityGroup

@typing_extensions.final
class DBSubnetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_SUBNET_GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    DB_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    db_subnet_group_description: builtins.str
    db_subnet_group_name: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_subnet_group_description: builtins.str = ...,
        db_subnet_group_name: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_subnet_group_description", b"db_subnet_group_description", "db_subnet_group_name", b"db_subnet_group_name", "resource_info", b"resource_info", "subnet_ids", b"subnet_ids", "tags", b"tags"]) -> None: ...

global___DBSubnetGroup = DBSubnetGroup

@typing_extensions.final
class EventSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    EVENT_CATEGORIES_FIELD_NUMBER: builtins.int
    SNS_TOPIC_ARN_FIELD_NUMBER: builtins.int
    SOURCE_IDS_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    @property
    def event_categories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    sns_topic_arn: builtins.str
    @property
    def source_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    source_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        event_categories: collections.abc.Iterable[builtins.str] | None = ...,
        sns_topic_arn: builtins.str = ...,
        source_ids: collections.abc.Iterable[builtins.str] | None = ...,
        source_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "event_categories", b"event_categories", "resource_info", b"resource_info", "sns_topic_arn", b"sns_topic_arn", "source_ids", b"source_ids", "source_type", b"source_type"]) -> None: ...

global___EventSubscription = EventSubscription

@typing_extensions.final
class OptionGroupOptionSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___OptionGroupOptionSetting = OptionGroupOptionSetting

@typing_extensions.final
class OptionGroupOptionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_SECURITY_GROUP_MEMBERSHIPS_FIELD_NUMBER: builtins.int
    OPTION_NAME_FIELD_NUMBER: builtins.int
    OPTION_SETTINGS_FIELD_NUMBER: builtins.int
    OPTION_VERSION_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_MEMBERSHIPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def db_security_group_memberships(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    option_name: builtins.str
    @property
    def option_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OptionGroupOptionSetting]: ...
    option_version: builtins.str
    port: builtins.int
    @property
    def vpc_security_group_memberships(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_security_group_memberships: collections.abc.Iterable[builtins.str] | None = ...,
        option_name: builtins.str = ...,
        option_settings: collections.abc.Iterable[global___OptionGroupOptionSetting] | None = ...,
        option_version: builtins.str = ...,
        port: builtins.int = ...,
        vpc_security_group_memberships: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_security_group_memberships", b"db_security_group_memberships", "option_name", b"option_name", "option_settings", b"option_settings", "option_version", b"option_version", "port", b"port", "resource_info", b"resource_info", "vpc_security_group_memberships", b"vpc_security_group_memberships"]) -> None: ...

global___OptionGroupOptionConfiguration = OptionGroupOptionConfiguration

@typing_extensions.final
class DBProxyAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTH_SCHEME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IAM_AUTH_FIELD_NUMBER: builtins.int
    SECRET_ARN_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    auth_scheme: builtins.str
    description: builtins.str
    iam_auth: builtins.str
    secret_arn: builtins.str
    user_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auth_scheme: builtins.str = ...,
        description: builtins.str = ...,
        iam_auth: builtins.str = ...,
        secret_arn: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_scheme", b"auth_scheme", "description", b"description", "iam_auth", b"iam_auth", "resource_info", b"resource_info", "secret_arn", b"secret_arn", "user_name", b"user_name"]) -> None: ...

global___DBProxyAuth = DBProxyAuth

@typing_extensions.final
class OptionGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENGINE_NAME_FIELD_NUMBER: builtins.int
    MAJOR_ENGINE_VERSION_FIELD_NUMBER: builtins.int
    OPTION_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    OPTION_GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    engine_name: builtins.str
    major_engine_version: builtins.str
    @property
    def option_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OptionGroupOptionConfiguration]: ...
    option_group_description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        engine_name: builtins.str = ...,
        major_engine_version: builtins.str = ...,
        option_configurations: collections.abc.Iterable[global___OptionGroupOptionConfiguration] | None = ...,
        option_group_description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["engine_name", b"engine_name", "major_engine_version", b"major_engine_version", "option_configurations", b"option_configurations", "option_group_description", b"option_group_description", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___OptionGroup = OptionGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_loadbalancers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1azure/azure_microsoft_network_loadbalancers.proto\x12\x31oak9.tython.azure.microsoft_network_loadbalancers\x1a\x13shared/shared.proto\"\xfa\x02\n\x1fMicrosoft_Network_loadBalancers\x12X\n\x0eload_balancers\x18\x01 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancers\x12\x81\x01\n$load_balancers_backend_address_pools\x18\x02 \x03(\x0b\x32S.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancersBackendAddressPools\x12y\n load_balancers_inbound_nat_rules\x18\x03 \x03(\x0b\x32O.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancersInboundNatRules\"\x9e\x02\n\x1cLoadBalancersInboundNatRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12!\n\x19\x66rontend_ip_configuration\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x15\n\rfrontend_port\x18\x05 \x01(\x05\x12\x14\n\x0c\x62\x61\x63kend_port\x18\x06 \x01(\x05\x12\x1f\n\x17idle_timeout_in_minutes\x18\x07 \x01(\x05\x12\x1a\n\x12\x65nable_floating_ip\x18\x08 \x01(\x08\x12\x18\n\x10\x65nable_tcp_reset\x18\t \x01(\x08\"\xf3\x01\n LoadBalancersBackendAddressPools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12v\n\x1fload_balancer_backend_addresses\x18\x04 \x03(\x0b\x32M.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancerBackendAddress\"\xb9\x08\n\rLoadBalancers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12X\n\x04tags\x18\x04 \x03(\x0b\x32J.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancers.TagsEntry\x12^\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_network_loadbalancers.ExtendedLocation\x12O\n\x03sku\x18\x06 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancerSku\x12n\n\x1a\x66rontend_ip_configurations\x18\x07 \x03(\x0b\x32J.oak9.tython.azure.microsoft_network_loadbalancers.FrontendIPConfiguration\x12\x64\n\x15\x62\x61\x63kend_address_pools\x18\x08 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network_loadbalancers.BackendAddressPool\x12\x62\n\x14load_balancing_rules\x18\t \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancingRule\x12H\n\x06probes\x18\n \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_loadbalancers.Probe\x12\\\n\x11inbound_nat_rules\x18\x0b \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network_loadbalancers.InboundNatRule\x12\\\n\x11inbound_nat_pools\x18\x0c \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_network_loadbalancers.InboundNatPool\x12W\n\x0eoutbound_rules\x18\r \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_loadbalancers.OutboundRule\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcd\x01\n\x0cOutboundRule\x12 \n\x18\x61llocated_outbound_ports\x18\x01 \x01(\x05\x12\"\n\x1a\x66rontend_ip_configurations\x18\x02 \x03(\t\x12\x1c\n\x14\x62\x61\x63kend_address_pool\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x18\n\x10\x65nable_tcp_reset\x18\x05 \x01(\x08\x12\x1f\n\x17idle_timeout_in_minutes\x18\x06 \x01(\x05\x12\x0c\n\x04name\x18\x07 \x01(\t\"\x84\x02\n\x0eInboundNatPool\x12!\n\x19\x66rontend_ip_configuration\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12!\n\x19\x66rontend_port_range_start\x18\x03 \x01(\x05\x12\x1f\n\x17\x66rontend_port_range_end\x18\x04 \x01(\x05\x12\x14\n\x0c\x62\x61\x63kend_port\x18\x05 \x01(\x05\x12\x1f\n\x17idle_timeout_in_minutes\x18\x06 \x01(\x05\x12\x1a\n\x12\x65nable_floating_ip\x18\x07 \x01(\x08\x12\x18\n\x10\x65nable_tcp_reset\x18\x08 \x01(\x08\x12\x0c\n\x04name\x18\t \x01(\t\"\xd7\x01\n\x0eInboundNatRule\x12!\n\x19\x66rontend_ip_configuration\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x15\n\rfrontend_port\x18\x03 \x01(\x05\x12\x14\n\x0c\x62\x61\x63kend_port\x18\x04 \x01(\x05\x12\x1f\n\x17idle_timeout_in_minutes\x18\x05 \x01(\x05\x12\x1a\n\x12\x65nable_floating_ip\x18\x06 \x01(\x08\x12\x18\n\x10\x65nable_tcp_reset\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x08 \x01(\t\"\x82\x01\n\x05Probe\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x1b\n\x13interval_in_seconds\x18\x03 \x01(\x05\x12\x18\n\x10number_of_probes\x18\x04 \x01(\x05\x12\x14\n\x0crequest_path\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xc1\x02\n\x11LoadBalancingRule\x12!\n\x19\x66rontend_ip_configuration\x18\x01 \x01(\t\x12\x1c\n\x14\x62\x61\x63kend_address_pool\x18\x02 \x01(\t\x12\r\n\x05probe\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x19\n\x11load_distribution\x18\x05 \x01(\t\x12\x15\n\rfrontend_port\x18\x06 \x01(\x05\x12\x14\n\x0c\x62\x61\x63kend_port\x18\x07 \x01(\x05\x12\x1f\n\x17idle_timeout_in_minutes\x18\x08 \x01(\x05\x12\x1a\n\x12\x65nable_floating_ip\x18\t \x01(\x08\x12\x18\n\x10\x65nable_tcp_reset\x18\n \x01(\x08\x12\x1d\n\x15\x64isable_outbound_snat\x18\x0b \x01(\x08\x12\x0c\n\x04name\x18\x0c \x01(\t\"\xac\x01\n\x12\x42\x61\x63kendAddressPool\x12\x10\n\x08location\x18\x01 \x01(\t\x12v\n\x1fload_balancer_backend_addresses\x18\x02 \x03(\x0b\x32M.oak9.tython.azure.microsoft_network_loadbalancers.LoadBalancerBackendAddress\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x88\x01\n\x1aLoadBalancerBackendAddress\x12\x17\n\x0fvirtual_network\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12/\n\'load_balancer_frontend_ip_configuration\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xe1\x01\n\x17\x46rontendIPConfiguration\x12\x1a\n\x12private_ip_address\x18\x01 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x02 \x01(\t\x12\"\n\x1aprivate_ip_address_version\x18\x03 \x01(\t\x12\x0e\n\x06subnet\x18\x04 \x01(\t\x12\x19\n\x11public_ip_address\x18\x05 \x01(\t\x12\x18\n\x10public_ip_prefix\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\r\n\x05zones\x18\x08 \x03(\t\"-\n\x0fLoadBalancerSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_loadbalancers_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOADBALANCERS_TAGSENTRY._options = None
  _LOADBALANCERS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_LOADBALANCERS._serialized_start=126
  _MICROSOFT_NETWORK_LOADBALANCERS._serialized_end=504
  _LOADBALANCERSINBOUNDNATRULES._serialized_start=507
  _LOADBALANCERSINBOUNDNATRULES._serialized_end=793
  _LOADBALANCERSBACKENDADDRESSPOOLS._serialized_start=796
  _LOADBALANCERSBACKENDADDRESSPOOLS._serialized_end=1039
  _LOADBALANCERS._serialized_start=1042
  _LOADBALANCERS._serialized_end=2123
  _LOADBALANCERS_TAGSENTRY._serialized_start=2080
  _LOADBALANCERS_TAGSENTRY._serialized_end=2123
  _OUTBOUNDRULE._serialized_start=2126
  _OUTBOUNDRULE._serialized_end=2331
  _INBOUNDNATPOOL._serialized_start=2334
  _INBOUNDNATPOOL._serialized_end=2594
  _INBOUNDNATRULE._serialized_start=2597
  _INBOUNDNATRULE._serialized_end=2812
  _PROBE._serialized_start=2815
  _PROBE._serialized_end=2945
  _LOADBALANCINGRULE._serialized_start=2948
  _LOADBALANCINGRULE._serialized_end=3269
  _BACKENDADDRESSPOOL._serialized_start=3272
  _BACKENDADDRESSPOOL._serialized_end=3444
  _LOADBALANCERBACKENDADDRESS._serialized_start=3447
  _LOADBALANCERBACKENDADDRESS._serialized_end=3583
  _FRONTENDIPCONFIGURATION._serialized_start=3586
  _FRONTENDIPCONFIGURATION._serialized_end=3811
  _LOADBALANCERSKU._serialized_start=3813
  _LOADBALANCERSKU._serialized_end=3858
  _EXTENDEDLOCATION._serialized_start=3860
  _EXTENDEDLOCATION._serialized_end=3906
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AccessPointAccessPointTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___AccessPointAccessPointTag = AccessPointAccessPointTag

@typing_extensions.final
class AccessPointPosixUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    GID_FIELD_NUMBER: builtins.int
    SECONDARY_GIDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    uid: builtins.str
    gid: builtins.str
    @property
    def secondary_gids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        uid: builtins.str = ...,
        gid: builtins.str = ...,
        secondary_gids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gid", b"gid", "resource_info", b"resource_info", "secondary_gids", b"secondary_gids", "uid", b"uid"]) -> None: ...

global___AccessPointPosixUser = AccessPointPosixUser

@typing_extensions.final
class AccessPointCreationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OWNER_UID_FIELD_NUMBER: builtins.int
    OWNER_GID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    owner_uid: builtins.str
    owner_gid: builtins.str
    permissions: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        owner_uid: builtins.str = ...,
        owner_gid: builtins.str = ...,
        permissions: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner_gid", b"owner_gid", "owner_uid", b"owner_uid", "permissions", b"permissions", "resource_info", b"resource_info"]) -> None: ...

global___AccessPointCreationInfo = AccessPointCreationInfo

@typing_extensions.final
class AccessPointRootDirectory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    CREATION_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    path: builtins.str
    @property
    def creation_info(self) -> global___AccessPointCreationInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        path: builtins.str = ...,
        creation_info: global___AccessPointCreationInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_info", b"creation_info", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_info", b"creation_info", "path", b"path", "resource_info", b"resource_info"]) -> None: ...

global___AccessPointRootDirectory = AccessPointRootDirectory

@typing_extensions.final
class AccessPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_TOKEN_FIELD_NUMBER: builtins.int
    ACCESS_POINT_TAGS_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_ID_FIELD_NUMBER: builtins.int
    POSIX_USER_FIELD_NUMBER: builtins.int
    ROOT_DIRECTORY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_token: builtins.str
    @property
    def access_point_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessPointAccessPointTag]: ...
    file_system_id: builtins.str
    @property
    def posix_user(self) -> global___AccessPointPosixUser: ...
    @property
    def root_directory(self) -> global___AccessPointRootDirectory: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_token: builtins.str = ...,
        access_point_tags: collections.abc.Iterable[global___AccessPointAccessPointTag] | None = ...,
        file_system_id: builtins.str = ...,
        posix_user: global___AccessPointPosixUser | None = ...,
        root_directory: global___AccessPointRootDirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["posix_user", b"posix_user", "resource_info", b"resource_info", "root_directory", b"root_directory"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_point_tags", b"access_point_tags", "client_token", b"client_token", "file_system_id", b"file_system_id", "posix_user", b"posix_user", "resource_info", b"resource_info", "root_directory", b"root_directory"]) -> None: ...

global___AccessPoint = AccessPoint

@typing_extensions.final
class EFS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_POINT_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_FIELD_NUMBER: builtins.int
    MOUNT_TARGET_FIELD_NUMBER: builtins.int
    @property
    def access_point(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AccessPoint]: ...
    @property
    def file_system(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileSystem]: ...
    @property
    def mount_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MountTarget]: ...
    def __init__(
        self,
        *,
        access_point: collections.abc.Iterable[global___AccessPoint] | None = ...,
        file_system: collections.abc.Iterable[global___FileSystem] | None = ...,
        mount_target: collections.abc.Iterable[global___MountTarget] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_point", b"access_point", "file_system", b"file_system", "mount_target", b"mount_target"]) -> None: ...

global___EFS = EFS

@typing_extensions.final
class FileSystemElasticFileSystemTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___FileSystemElasticFileSystemTag = FileSystemElasticFileSystemTag

@typing_extensions.final
class FileSystemLifecyclePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRANSITION_TO_I_A_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    transition_to_i_a: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        transition_to_i_a: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "transition_to_i_a", b"transition_to_i_a"]) -> None: ...

global___FileSystemLifecyclePolicy = FileSystemLifecyclePolicy

@typing_extensions.final
class FileSystemBackupPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___FileSystemBackupPolicy = FileSystemBackupPolicy

@typing_extensions.final
class FileSystem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class FileSystemPolicyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_TAGS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_POLICIES_FIELD_NUMBER: builtins.int
    PERFORMANCE_MODE_FIELD_NUMBER: builtins.int
    PROVISIONED_THROUGHPUT_IN_MIBPS_FIELD_NUMBER: builtins.int
    THROUGHPUT_MODE_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_POLICY_FIELD_NUMBER: builtins.int
    BACKUP_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    encrypted: builtins.bool
    @property
    def file_system_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileSystemElasticFileSystemTag]: ...
    kms_key_id: builtins.str
    @property
    def lifecycle_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileSystemLifecyclePolicy]: ...
    performance_mode: builtins.str
    provisioned_throughput_in_mibps: builtins.float
    throughput_mode: builtins.str
    @property
    def file_system_policy(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def backup_policy(self) -> global___FileSystemBackupPolicy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encrypted: builtins.bool = ...,
        file_system_tags: collections.abc.Iterable[global___FileSystemElasticFileSystemTag] | None = ...,
        kms_key_id: builtins.str = ...,
        lifecycle_policies: collections.abc.Iterable[global___FileSystemLifecyclePolicy] | None = ...,
        performance_mode: builtins.str = ...,
        provisioned_throughput_in_mibps: builtins.float = ...,
        throughput_mode: builtins.str = ...,
        file_system_policy: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        backup_policy: global___FileSystemBackupPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backup_policy", b"backup_policy", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_policy", b"backup_policy", "encrypted", b"encrypted", "file_system_policy", b"file_system_policy", "file_system_tags", b"file_system_tags", "kms_key_id", b"kms_key_id", "lifecycle_policies", b"lifecycle_policies", "performance_mode", b"performance_mode", "provisioned_throughput_in_mibps", b"provisioned_throughput_in_mibps", "resource_info", b"resource_info", "throughput_mode", b"throughput_mode"]) -> None: ...

global___FileSystem = FileSystem

@typing_extensions.final
class MountTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    file_system_id: builtins.str
    ip_address: builtins.str
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        file_system_id: builtins.str = ...,
        ip_address: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_system_id", b"file_system_id", "ip_address", b"ip_address", "resource_info", b"resource_info", "security_groups", b"security_groups", "subnet_id", b"subnet_id"]) -> None: ...

global___MountTarget = MountTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DatastoreIndexXProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIRECTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    direction: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        direction: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["direction", b"direction", "name", b"name"]) -> None: ...

global___DatastoreIndexXProperties = DatastoreIndexXProperties

@typing_extensions.final
class DatastoreIndexXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___DatastoreIndexXTimeouts = DatastoreIndexXTimeouts

@typing_extensions.final
class DatastoreIndex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANCESTOR_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INDEX_ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ancestor: builtins.str
    id: builtins.str
    index_id: builtins.str
    kind: builtins.str
    project: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatastoreIndexXProperties]: ...
    @property
    def timeouts(self) -> global___DatastoreIndexXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ancestor: builtins.str = ...,
        id: builtins.str = ...,
        index_id: builtins.str = ...,
        kind: builtins.str = ...,
        project: builtins.str = ...,
        properties: collections.abc.Iterable[global___DatastoreIndexXProperties] | None = ...,
        timeouts: global___DatastoreIndexXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ancestor", b"ancestor", "id", b"id", "index_id", b"index_id", "kind", b"kind", "project", b"project", "properties", b"properties", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DatastoreIndex = DatastoreIndex
